@@ -2,10 +2,9 @@
 pyvitemadose init
 """
 
-
+from os import sys
 from pyvitemadose.args import compute_args
 from pyvitemadose.pyvitemadose import find
-from pyvitemadose.update import update
 
 def pyvitemadose():
     """
@@ -13,8 +12,14 @@ def pyvitemadose():
     """
     args = compute_args()
 
-
     if args.update:
-        update()
+        try:
+            from pyvitemadose.update import update
+            update()
+        except ImportError:
+            print("update is disabled. You seem to use autoexec version")    
     if args.departement:
         find(args.departement)
+    sys.exit(0)
+
+pyvitemadose()
\ No newline at end of file
